@@ -9,9 +9,9 @@ use crate::{
 use super::{
     bin_column::{BinColumn, BinColumnIt, BinColumnWriter},
     column_with_indicator::{
-        NullableSlice, OptBitColumn, OptDateColumn, OptF32Column, OptF64Column, OptI16Column,
-        OptI32Column, OptI64Column, OptI8Column, OptTimeColumn, OptTimestampColumn, OptU8Column,
-        NullableSliceMut,
+        NullableSlice, NullableSliceMut, OptBitColumn, OptDateColumn, OptF32Column, OptF64Column,
+        OptI16Column, OptI32Column, OptI64Column, OptI8Column, OptTimeColumn, OptTimestampColumn,
+        OptU8Column,
     },
     text_column::{TextColumn, TextColumnIt, TextColumnWriter},
     BufferDescription, BufferKind, CharColumn, WCharColumn,
@@ -637,7 +637,10 @@ unsafe impl RowSetBuffer for ColumnarRowSet {
 
     unsafe fn bind_to_cursor(&mut self, cursor: &mut impl Cursor) -> Result<(), Error> {
         for (col_number, column) in &mut self.columns {
-            cursor.stmt().bind_col(*col_number, column)?;
+            cursor
+                .stmt()
+                .bind_col(*col_number, column)
+                .into_result(cursor.stmt())?;
         }
         Ok(())
     }
@@ -650,7 +653,8 @@ unsafe impl ParameterCollection for &ColumnarRowSet {
 
     unsafe fn bind_parameters_to(self, stmt: &mut StatementImpl<'_>) -> Result<(), Error> {
         for &(parameter_number, ref buffer) in &self.columns {
-            stmt.bind_input_parameter(parameter_number, buffer)?;
+            stmt.bind_input_parameter(parameter_number, buffer)
+                .into_result(stmt)?;
         }
         Ok(())
     }
