@@ -13,8 +13,8 @@ mod connection;
 mod data_type;
 mod diagnostics;
 mod environment;
-mod error;
 mod logging;
+mod sql_result;
 mod statement;
 
 pub use {
@@ -26,7 +26,8 @@ pub use {
     data_type::DataType,
     diagnostics::{Record, State},
     environment::Environment,
-    error::Error,
+    logging::log_diagnostics,
+    sql_result::SqlResult,
     statement::{ParameterDescription, Statement, StatementImpl},
 };
 
