@@ -221,13 +221,39 @@ fn describe_columns() {
     assert_eq!(kind, cursor.col_data_type(11).unwrap());
 }
 
-#[test]
-fn text_buffer() {
-    let query = "SELECT title, year FROM Movies ORDER BY year;";
-    let conn = ENV
-        .connect_with_connection_string(MSSQL_CONNECTION)
-        .unwrap();
-    let cursor = conn.execute(query, ()).unwrap().unwrap();
+/// Fetch text from data source using the TextBuffer type
+#[test_case(MSSQL; "Microsoft SQL Server")]
+#[test_case(MARIADB; "Maria DB")]
+#[test_case(SQLITE_3; "SQLite 3")]
+fn text_buffer(profile: &Profile) {
+    let table_name = "TextBuffer";
+    let conn = profile.connection().unwrap();
+    setup_empty_table(
+        &conn,
+        profile.index_type,
+        table_name,
+        &["VARCHAR(255)", "INT"],
+    )
+    .unwrap();
+
+    // Insert data
+    let insert = format!("INSERT INTO {} (a,b) VALUES (?,?), (?,?),(?,?)", table_name);
+    conn.execute(
+        &insert,
+        (
+            &"Interstellar".into_parameter(),
+            &None::<i32>.into_parameter(),
+            &"2001: A Space Odyssey".into_parameter(),
+            &1968,
+            &"Jurassic Park".into_parameter(),
+            &1993,
+        ),
+    )
+    .unwrap();
+
+    let query = format!("SELECT a,b FROM {} ORDER BY id;", table_name);
+    let cursor = conn.execute(&query, ()).unwrap().unwrap();
+    // Cursor to string helper utilizes the text buffer
     let actual = cursor_to_string(cursor);
     let expected = "Interstellar,NULL\n2001: A Space Odyssey,1968\nJurassic Park,1993";
     assert_eq!(expected, actual);
@@ -253,48 +279,6 @@ fn column_attributes() {
     assert_eq!("year", name.to_string().unwrap());
 }
 
-#[test]
-fn prices() {
-    let conn = ENV
-        .connect_with_connection_string(MSSQL_CONNECTION)
-        .unwrap();
-    let sql = "SELECT id,day,time,product,price FROM Sales ORDER BY id;";
-    let cursor = conn.execute(sql, ()).unwrap().unwrap();
-
-    // Test names
-    let mut buf = Vec::new();
-
-    let mut name = |column_number| {
-        cursor.col_name(column_number, &mut buf).unwrap();
-        std::char::decode_utf16(buf.iter().copied())
-            .collect::<Result<String, _>>()
-            .unwrap()
-    };
-
-    assert_eq!("id", name(1));
-    assert_eq!("day", name(2));
-    assert_eq!("time", name(3));
-    assert_eq!("product", name(4));
-    assert_eq!("price", name(5));
-
-    // Test types
-
-    assert_eq!(
-        DataType::Decimal {
-            precision: 10,
-            scale: 2
-        },
-        cursor.col_data_type(5).unwrap()
-    );
-
-    // Test binding id int buffer
-    let batch_size = 10;
-    assert_eq!(DataType::Integer, cursor.col_data_type(1).unwrap());
-    let id_buffer = SingleColumnRowSetBuffer::new(batch_size);
-    let mut row_set_cursor = cursor.bind_buffer(id_buffer).unwrap();
-    assert_eq!(&[1, 2, 3], row_set_cursor.fetch().unwrap().unwrap().get());
-}
-
 /// Bind a CHAR column to a character buffer.
 #[test_case(MSSQL; "Microsoft SQL Server")]
 #[test_case(MARIADB; "Maria DB")]
@@ -2172,9 +2156,7 @@ fn insert_truncated_value(profile: &Profile) {
 #[test_case(MARIADB; "Maria DB expected fail inconclusive")]
 #[test_case(SQLITE_3; "SQLite 3")]
 fn insert_truncated_var_char_array(profile: &Profile) {
-    let conn = ENV
-        .connect_with_connection_string(profile.connection_string)
-        .unwrap();
+    let conn = profile.connection().unwrap();
     let table_name = "InsertedTruncatedVarCharArray";
 
     // Prepare table content
